/**
 * This file adds functionality to the Theme Customizer live preview. To leverage
 * this, set your custom settings to 'postMessage' and then add your handling
 * here. Your javascript should grab settings from customizer controls, and
 * then make any necessary changes to the page using jQuery.
 */
(function($) {

	// Toggle the sticky header.
	wp.customize('sh2020_enable_header_sticky', function(value) {
		value.bind(function(newval) {
			window.scrollTo(0, 0);
			if (true === newval) {
				var height = wp.customize( 'sh2020_header_sticky_min_height' ).get();
				$('body').addClass('sticky-header');
				$('.sticky-header').css('padding-top', height);
				$('.sticky-header').css('scroll-padding', height);
				$('.sticky-header .primary-menu').addClass('in-customizer-preview');
			} else {
				$('body').removeClass('sticky-header');
				$('body').css('padding-top', 0);
				$('body').css('scroll-padding', 0);
				$('.primary-menu').removeClass('in-customizer-preview');
			}
		});
	});

	// Update sticky header height and spacing settings.
	wp.customize('sh2020_header_sticky_min_height', function(value) {
		value.bind(function(newval) {
			window.scrollTo(0, 0);
			sh2020_sticky_header_adjust_maxified();
		});
	});
	wp.customize('sh2020_header_sticky_vertical_spacing', function(value) {
		value.bind(function(newval) {
			var headerid = wp.customize( 'sh2020_header_sticky_selector' ).get();
			var height = wp.customize( 'sh2020_header_sticky_min_height' ).get();

			$('.sticky-header ' + headerid + ' .header-inner').css('padding', newval + ' 0');
			$('.sticky-header ' + headerid + ' .custom-logo').css('max-height', 'calc(' + height + ' - (' + newval + ' * 2) )');
		});
	});

	// Update sticky minified header height and spacing settings.
	wp.customize('sh2020_header_sticky_min_height_minified', function(value) {
		value.bind(function(newval) {
			sh2020_sticky_header_adjust_minified();
			window.scrollTo(0, 200);
		});
	});
	wp.customize('sh2020_header_sticky_vertical_spacing_minified', function(value) {
		value.bind(function(newval) {
			var headerid = wp.customize( 'sh2020_header_sticky_selector' ).get();
			var height =  wp.customize( 'sh2020_header_sticky_min_height_minified' ).get();

			$('.sticky-header ' + headerid + '.sticky-header-minified .header-inner').css('padding', newval + ' 0');
			$('.sticky-header ' + headerid + '.sticky-header-minified .custom-logo').css('max-height', 'calc(' + height + ' - (' + newval + ' * 2) )');
		});
	});

	// Update sticky mobile/tablet header height and spacing settings.
	wp.customize('sh2020_header_sticky_min_height_mobile', function(value) {
		value.bind(function(newval) {
			var w = sh2020_detect_current_device_view();
			if (w == 'mobile') {
				var headerid = wp.customize( 'sh2020_header_sticky_selector' ).get();
				var spacing  = wp.customize( 'sh2020_header_sticky_vertical_spacing_mobile' ).get();
				$('.sticky-header').css('padding-top', newval);
				$('.sticky-header').css('scroll-padding', newval);
				$('.sticky-header ' + headerid).css('min-height', newval);
				$('.sticky-header ' + headerid).css('height', newval);
				$('.sticky-header.template-cover .entry-header').css('bottom', newval);
				$('.sticky-header ' + headerid + ' .custom-logo').css('max-height', 'calc(' + newval + ' - (' + spacing + ' * 2) )');
			}
		});
	});
	wp.customize('sh2020_header_sticky_vertical_spacing_mobile', function(value) {
		value.bind(function(newval) {
			var headerid = wp.customize( 'sh2020_header_sticky_selector' ).get();
			var height =  wp.customize( 'sh2020_header_sticky_min_height_mobile' ).get();

			$('.sticky-header ' + headerid + ' .header-inner').css('padding', newval + ' 0');
			$('.sticky-header ' + headerid + ' .custom-logo').css('max-height', 'calc(' + height + ' - (' + newval + ' * 2) )');
		});
	});

	// Update sticky header background color.
	wp.customize('sh2020_header_sticky_bg_color', function(value) {
		value.bind(function(newval) {
			var headerid = wp.customize( 'sh2020_header_sticky_selector' ).get();

			$('.sticky-header ' + headerid).css('background-color', newval);
			$('.sticky-header ' + headerid).css('background', newval);
		});
	});

	// Update sticky header text color.
	wp.customize('sh2020_header_sticky_text_color', function(value) {
		value.bind(function(newval) {
			$('.sticky-header .site-description').css('color', newval);
			$('.sticky-header .site-title, .sticky-header .site-title *').css('color', newval);
			$('.sticky-header:not(.overlay-header) .nav-toggle .toggle-text').css('color', newval);
			$('.sticky-header:not(.overlay-header) .toggle.nav-toggle .toggle-inner .toggle-text').css('color', newval);
			$('.sticky-header:not(.overlay-header) .toggle.search-toggle .toggle-inner .toggle-text').css('color', newval);
			$('.sticky-header.overlay-header .header-inner').css('color', newval);
			sh2020_handle_pseudo_elements();
		});
	});

	// Update sticky header icons and menu icons color.
	wp.customize('sh2020_header_sticky_icons_color', function(value) {
		value.bind(function(newval) {
			$('.sticky-header .toggle-icon').css('color', newval);
			$('.sticky-header .toggle-wrapper .svg-icon').css('color', newval);
		});
	});
	wp.customize('sh2020_header_sticky_menu_icons_color', function(value) {
		value.bind(function(newval) {
			$('body.sticky-header .icon').css('color', newval);
			$('body.sticky-header.overlay-header .primary-menu > li > .icon').css('color', newval);
			$('body.sticky-header:not(.overlay-header) .primary-menu > li > .icon').css('color', newval);
			sh2020_handle_pseudo_elements();
		});
	});
	wp.customize('sh2020_header_sticky_menu_current_links_color', function(value) {
		value.bind(function(newval) {
			$('body.sticky-header:not(.overlay-header) .primary-menu > li.current-menu-item > a').css('color', newval);
			$('body.sticky-header:not(.overlay-header) .primary-menu .sub-menu > li.current-menu-item > a').css('color', newval);
		});
	});
	wp.customize('sh2020_header_sticky_menu_no_decoration', function(value) {
		value.bind(function(newval) {
			if (true === newval) {
				$('body.sticky-header:not(.overlay-header) .primary-menu a').attr('style','text-decoration: none !important; border-bottom: 0 !important');
			} else {
				$('body.sticky-header:not(.overlay-header) .primary-menu a').attr('style','');
			}
		});
	});

	// Update sticky header submenu background color.
	wp.customize('sh2020_header_sticky_submenu_bg_color', function(value) {
		value.bind(function(newval) {
			$('.sticky-header.overlay-header .primary-menu ul').css('background', newval);
			$('.sticky-header:not(.overlay-header) .primary-menu ul').css('background', newval);
			$('body.sticky-header.overlay-header .primary-menu > li > ul:after').css('border-bottom-color', newval);
			$('body.sticky-header:not(.overlay-header) .primary-menu > li > ul:after').css('border-bottom-color', newval);
			$('body.sticky-header.overlay-header .primary-menu ul ul:after').css('border-left-color', newval);
			$('body.sticky-header:not(.overlay-header) .primary-menu ul ul:after').css('border-left-color', newval);
			sh2020_handle_pseudo_elements();
		});
	});

	// Update sticky header links color.
	wp.customize('sh2020_header_sticky_links_color', function(value) {
		value.bind(function(newval) {
			$('.sticky-header.overlay-header .primary-menu a').css('color', newval);
			$('.sticky-header:not(.overlay-header) .primary-menu > li > a').css('color', newval);
			$('.sticky-header:not(.overlay-header) .primary-menu .sub-menu > li > a').css('color', newval);
		});
	});
	wp.customize('sh2020_header_sticky_links_hover_color', function(value) {
		value.bind(function(newval) {
			sh2020_handle_pseudo_elements();
		});
	});

	// Update sticky header box shadow size.
	wp.customize('sh2020_header_sticky_box_shadow_size', function(value) {
		value.bind(function(newval) {
			var headerid = wp.customize( 'sh2020_header_sticky_selector' ).get();
			var color = wp.customize( 'sh2020_header_sticky_box_shadow_color' ).get();
			$('.sticky-header ' + headerid).css('box-shadow', '0 0 ' + newval + ' 0 ' + color);
		});
	});
	wp.customize('sh2020_header_sticky_box_shadow_color', function(value) {
		value.bind(function(newval) {
			var headerid = wp.customize( 'sh2020_header_sticky_selector' ).get();
			var size = wp.customize( 'sh2020_header_sticky_box_shadow_size' ).get();
			$('.sticky-header ' + headerid).css('box-shadow', '0 0 ' + size + ' 0 ' + newval);
		});
	});

	// Toggle the menu and search labels.
	wp.customize('sh2020_header_sticky_hide_menu_label', function(value) {
		value.bind(function(newval) {
			if (true === newval) {
				$('.sticky-header.overlay-header .toggle.nav-toggle .toggle-inner .toggle-text').css('display', 'none');
				$('.sticky-header:not(.overlay-header) .toggle.nav-toggle .toggle-inner .toggle-text').css('display', 'none');
			} else {
				$('.sticky-header.overlay-header .toggle.nav-toggle .toggle-inner .toggle-text').css('display', 'inherit');
				$('.sticky-header:not(.overlay-header) .toggle.nav-toggle .toggle-inner .toggle-text').css('display', 'inherit');
			}
		});
	});
	wp.customize('sh2020_header_sticky_hide_search_label', function(value) {
		value.bind(function(newval) {
			if (true === newval) {
				$('.sticky-header.overlay-header .toggle.search-toggle .toggle-inner .toggle-text').css('display', 'none');
				$('.sticky-header:not(.overlay-header) .toggle.search-toggle .toggle-inner .toggle-text').css('display', 'none');
			} else {
				$('.sticky-header.overlay-header .toggle.search-toggle .toggle-inner .toggle-text').css('display', 'inherit');
				$('.sticky-header:not(.overlay-header) .toggle.search-toggle .toggle-inner .toggle-text').css('display', 'inherit');
			}
		});
	});

	function sh2020_detect_current_device_view() {
		var w = $('body').width();
		if (w <= 320) {
			return 'mobile';
		} else if (w <= 720) {
			return 'tablet';
		} else {
			return 'desktop';
		}
	}

	function sh2020_handle_pseudo_elements() {
		var is_pro = wp.customize( 'sh2020_sticky_header_pro_version' ).get();
		var bcolor = wp.customize( 'sh2020_header_sticky_submenu_bg_color' ).get();
		var content = 'body.sticky-header.overlay-header .primary-menu > li > ul:after, body.sticky-header:not(.overlay-header) .primary-menu > li > ul:after {border-bottom-color:' + bcolor + '!important} body.sticky-header.overlay-header .primary-menu ul ul:after, body.sticky-header:not(.overlay-header) .primary-menu ul ul:after {border-left-color:' + bcolor + '!important}';

		if ( is_pro ) {
			var tcolor = wp.customize( 'sh2020_header_sticky_text_color' ).get();
			var hcolor = wp.customize( 'sh2020_header_sticky_links_hover_color' ).get();
			var icolor = wp.customize( 'sh2020_header_sticky_menu_icons_color' ).get();
			content += ' .sticky-header .header-inner .toggle-wrapper:before, body.sticky-header .header-inner .toggle-wrapper:before {background:' + tcolor + '!important}';
			content += ' .sticky-header.overlay-header .primary-menu li:hover > a, .sticky-header:not(.overlay-header) .primary-menu li:hover > a {color:' + hcolor + '!important}';
			content += ' body.sticky-header .icon, body.sticky-header.overlay-header .primary-menu > li > .icon, body.sticky-header:not(.overlay-header) .primary-menu > li > .icon {color:' + icolor + '!important}';
		}

		$('head').remove('#in-customizer-preview-2020');
		$('head').append('<style id="in-customizer-preview-2020">' + content + '</style>');
	}

	function sh2020_sticky_header_adjust_minified() {
		var headerid = wp.customize( 'sh2020_header_sticky_selector' ).get();
		var height   = wp.customize( 'sh2020_header_sticky_min_height_minified' ).get();
		var spacing  = wp.customize( 'sh2020_header_sticky_vertical_spacing_minified' ).get();
		$('.sticky-header').css('padding-top', height);
		$('.sticky-header').css('scroll-padding', height);
		$('.sticky-header ' + headerid + '.sticky-header-minified').css('min-height', height);
		$('.sticky-header ' + headerid + '.sticky-header-minified').css('height', height);
		$('.sticky-header.template-cover .entry-header').css('bottom', height);
		$('.sticky-header ' + headerid + '.sticky-header-minified .header-inner').css('padding', spacing + ' 0');
		$('.sticky-header ' + headerid + '.sticky-header-minified .custom-logo').css('max-height', 'calc(' + height + ' - (' + spacing + ' * 2) )');
	}

	function sh2020_sticky_header_adjust_maxified() {
		var headerid = wp.customize( 'sh2020_header_sticky_selector' ).get();
		var height   = wp.customize( 'sh2020_header_sticky_min_height' ).get();
		var spacing  = wp.customize( 'sh2020_header_sticky_vertical_spacing' ).get();
		$('.sticky-header').css('padding-top', height);
		$('.sticky-header').css('scroll-padding', height);
		$('.sticky-header ' + headerid).css('min-height', height);
		$('.sticky-header ' + headerid).css('height', height);
		$('.sticky-header.template-cover .entry-header').css('bottom', height);
		$('.sticky-header ' + headerid + ' .header-inner').css('padding', spacing + ' 0');
		$('.sticky-header ' + headerid + ' .custom-logo').css('max-height', 'calc(' + height + ' - (' + spacing + ' * 2) )');
	}

	window.addEventListener('stickyHeaderMinified', function(event) {
		event.preventDefault();
		var w = sh2020_detect_current_device_view();
		if (w != 'mobile' && w != 'tablet') {
			sh2020_sticky_header_adjust_minified();
		}
	});
	window.addEventListener('stickyHeaderMaxified', function(event) {
		event.preventDefault();
		var w = sh2020_detect_current_device_view();
		if (w != 'mobile' && w != 'tablet') {
			sh2020_sticky_header_adjust_maxified();
		}
	});

})(jQuery);
