<?php
/**
 * Plugin Name: Sticky Header 2020
 * Plugin URI: https://iuliacazan.ro/sticky-header-2020/
 * Description: This plugin appends custom functionality to the native customizer and provides the settings for making the header sticky, with settings for scroll minification, shadow, background, spacing, text, menu and icons colors, etc. This is compatible with Twenty Twenty theme.
 * Text Domain: sh2020
 * Domain Path: /langs
 * Version: 1.1
 * Author: Iulia Cazan
 * Author URI: https://profiles.wordpress.org/iulia-cazan
 * Donate link: https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=JJA37EHZXWUTJ
 * License: GPL2
 *
 * @package sticky-header-2020
 *
 * Copyright (C) 2019-2020 Iulia Cazan
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

define( 'STICKY_HEADER_2020_VER', 1.1 );

if ( ! class_exists( 'Sticky_Header_2020' ) ) {

	/**
	 * Customizer additional settings.
	 */
	class Sticky_Header_2020 {
		const DEFAULT_HEIGHT            = '140px';
		const DEFAULT_SPACING           = '28px';
		const DEFAULT_HEIGHT_MINI       = '110px';
		const DEFAULT_SPACING_MINI      = '10px';
		const DEFAULT_HEIGHT_MOBILE     = '84px';
		const DEFAULT_SPACING_MOBILE    = '5px';
		const DEFAULT_SHADOW_SIZE       = '1em';
		const DEFAULT_SHADOW_COLOR      = 'rgba(0,0,0,0.8)';
		const DEFAULT_COLOR_BG          = '#ffffff';
		const DEFAULT_COLOR_BG_SUBMENU  = '#eeeeee';
		const DEFAULT_COLOR_TEXT        = '#000000';
		const DEFAULT_COLOR_ICONS       = '#444444';
		const DEFAULT_COLOR_LINKS       = '#000000';
		const DEFAULT_COLOR_LINKS_HOVER = '#ff0000';
		const DEFAULT_SELECTOR          = '#site-header'; // Maybe #masthead for older.
		const PRO_LABEL                 = '<b class="sh2020-sticky-header-pro-label">PRO</b>';
		const LINK_PRO_VERSION          = 'https://iuliacazan.ro/wordpress-extension/sticky-header-2020-pro/';
		const LINK_LIGHT_VERSION        = 'https://iuliacazan.ro/sticky-header-2020/';
		const ASSETS_VER                = '20191118.0805';
		const PLUGIN_NAME               = 'Sticky Header 2020';
		const PLUGIN_SUPPORT_URL        = 'https://wordpress.org/support/plugin/sticky-header-2020/';
		const PLUGIN_TRANSIENT          = 'sh2020-plugin-notice';

		/**
		 * Class instance.
		 *
		 * @var object
		 */
		private static $instance;

		/**
		 * Display the PRO label in PRO version.
		 *
		 * @var boolean
		 */
		public static $show_pro = true;

		/**
		 * Get active object instance
		 *
		 * @access public
		 * @static
		 * @return object
		 */
		public static function get_instance() {
			if ( ! self::$instance ) {
				self::$instance = new Sticky_Header_2020();
			}
			return self::$instance;
		}

		/**
		 * Class constructor. Includes constants and init methods.
		 *
		 * @access public
		 * @return void
		 */
		public function __construct() {
			$this->init();
		}

		/**
		 * Run action and filter hooks.
		 *
		 * @access private
		 * @return void
		 */
		private function init() {
			$class = get_called_class();

			// Check if the plugin should show or hide hints.
			add_action( 'init', array( $class, 'check_hints' ) );

			// Setup the Theme Customizer settings and controls.
			add_action( 'customize_register', array( $class, 'register' ) );

			// Trigger the transients reset on customizer save.
			add_action( 'customize_save_after', array( $class, 'update_custom_styles' ), 99 );
			add_action( 'customize_save_after', array( $class, 'update_custom_scripts' ), 99 );

			// Output custom CSS to live site.
			add_action( 'wp_enqueue_scripts', array( $class, 'enqueue_custom_styles' ) );

			// Enqueue the customizer assets.
			add_action( 'customize_preview_init', array( $class, 'sticky_header_2020_customizer_live_preview' ) );

			// Enqueue the customizer assets.
			add_filter( 'body_class', array( $class, 'sticky_header_2020_class' ), 90 );

			// Load translation.
			add_action( 'plugins_loaded', array( $class, 'load_textdomain' ) );

			// Versions updates notes.
			add_action( 'admin_notices', array( $class, 'admin_notices' ) );
			add_action( 'wp_ajax_sh2020-plugin-deactivate-notice', array( $class, 'admin_notices_cleanup' ) );

			// Setup custom plugin links.
			add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $class, 'plugin_action_links' ) );
		}

		/**
		 * Check if the hints are turned on/off.
		 */
		public static function check_hints() {
			$updated = false;
			if ( ! empty( $_SERVER['SCRIPT_NAME'] ) && substr_count( $_SERVER['SCRIPT_NAME'], 'customize.php' ) ) {
				$show = filter_input( INPUT_GET, 'sh2020-show-hints', FILTER_DEFAULT );
				if ( 'on' === $show ) {
					set_theme_mod( 'sh2020_show_hints', true );
					self::$show_pro = true;
					$updated        = true;
				} else {
					$hide = filter_input( INPUT_GET, 'sh2020-hide-hints', FILTER_DEFAULT );
					if ( 'on' === $hide ) {
						set_theme_mod( 'sh2020_show_hints', false );
						self::$show_pro = false;
						$updated        = true;
					}
				}
			}

			if ( true === $updated ) {
				$customizer = 'sh2020_sticky_header_options';
				if ( self::is_pro() ) {
					if ( true === self::$show_pro ) {
						$customizer = 'sh2020_sticky_header_options_pro';
					} else {
						$customizer = 'sh2020_sticky_header_options_pro_simple';
					}
				}
				wp_redirect( esc_url( admin_url( 'customize.php?autofocus[section]=' . $customizer ) ) );
				exit;
			} else {
				self::$show_pro = get_theme_mod( 'sh2020_show_hints' );
			}
		}

		/**
		 * Check if this is the PRO version.
		 *
		 * @return boolean
		 */
		public static function is_pro() {
			if ( file_exists( dirname( __FILE__ ) . '/pro-settings.php' ) ) {
				return true;
			}
			return false;
		}

		/**
		 * Register customizer options.
		 *
		 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
		 */
		public static function register( $wp_customize ) {
			// Include the custom rgba control class.
			require_once dirname( __FILE__ ) . '/classes/class-sh2020-customize-rgba-color-control.php';
			require_once dirname( __FILE__ ) . '/classes/class-sh2020-customize-simple-text-control.php';

			if ( self::is_pro() ) {
				if ( true === self::$show_pro ) {
					define( 'STICKY_HEADER_2020_SECTION', 'sh2020_sticky_header_options_pro' );
				} else {
					define( 'STICKY_HEADER_2020_SECTION', 'sh2020_sticky_header_options_pro_simple' );
				}
				if ( file_exists( dirname( __FILE__ ) . '/pro-settings.php' ) ) {
					require_once dirname( __FILE__ ) . '/pro-settings.php';
				}
			} else {
				define( 'STICKY_HEADER_2020_SECTION', 'sh2020_sticky_header_options' );
			}

			// Theme Options.
			$wp_customize->add_section(
				STICKY_HEADER_2020_SECTION,
				array(
					'title'       => __( 'Sticky Header', 'sh2020' ),
					'priority'    => 41,
					'capability'  => 'edit_theme_options',
					'description' => __( 'Here you can adjust specific settings for the Twenty Twenty theme sticky header. Please note that the settings below apply if the sticky header is enabled.', 'sh2020' ),
					'attrs'       => array(
						'class' => 'no-pro-label',
					),
					'attributes'       => array(
						'class' => 'no-pro-label',
					),
					'class' => 'no-pro-label',
				)
			);

			if ( self::is_pro() ) {
				if ( true === self::$show_pro ) {
					// Append general version notice.
					self::append_simple_text(
						$wp_customize,
						'header_sticky_custom_text_0',
						'',
						sprintf(
							// Translators: %1$s - pro version label, %2$s - link, %3$s - end link.
							__( 'Thank you for purchasing the %1$s version!<br>See more %2$sdetails%3$s.', 'sh2020' ),
							self::PRO_LABEL,
							'<a href="' . self::LINK_PRO_VERSION . '" target="_blank">',
							'</a>'
						),
						0
					);
				}
			} else {
				self::append_simple_text(
					$wp_customize,
					'header_sticky_custom_text_0',
					'',
					sprintf(
						// Translators: %1$s - pro version label, %2$s - link, %3$s - end link.
						__( 'You are using the free version, some settings are available only in the %1$s version.<br>See more %2$sdetails%3$s.', 'sh2020' ),
						self::PRO_LABEL,
						'<a href="' . self::LINK_PRO_VERSION . '" target="_blank">',
						'</a>'
					),
					0
				);
			}

			// The general header wrapper ID.
			$wp_customize->add_setting(
				'sh2020_header_sticky_selector',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => self::DEFAULT_SELECTOR,
					'sanitize_callback' => 'sanitize_text_field',
					'transport'         => 'postMessage',
				)
			);
			$wp_customize->add_control(
				'sh2020_header_sticky_selector',
				array(
					'type'        => 'text',
					'section'     => STICKY_HEADER_2020_SECTION,
					'priority'    => 1,
					'label'       => __( 'Header Selector (ID)', 'sh2020' ),
					'description' => __( 'default', 'sh2020' ) . ' ' . self::DEFAULT_SELECTOR,
					'input_attrs' => array(
						'style'       => 'width: 50%',
						'placeholder' => self::DEFAULT_HEIGHT,
					),
				)
			);

			// Enable sticky header.
			$wp_customize->add_setting(
				'sh2020_enable_header_sticky',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => false,
					'sanitize_callback' => array( get_called_class(), 'sanitize_checkbox' ),
					'transport'         => 'postMessage',
				)
			);
			$wp_customize->add_control(
				'sh2020_enable_header_sticky',
				array(
					'type'     => 'checkbox',
					'section'  => STICKY_HEADER_2020_SECTION,
					'priority' => 2,
					'label'    => __( 'Make the header sticky', 'sh2020' ),
				)
			);

			// Enable keeps sticky header settings.
			$wp_customize->add_setting(
				'sh2020_enable_header_sticky_keep_setting',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => false,
					'sanitize_callback' => array( get_called_class(), 'sanitize_checkbox' ),
					'transport'         => 'postMessage',
				)
			);
			$wp_customize->add_control(
				'sh2020_enable_header_sticky_keep_setting',
				array(
					'type'     => 'checkbox',
					'section'  => STICKY_HEADER_2020_SECTION,
					'priority' => 2,
					'label'    => __( 'Remove the header sticky settings when the plugin is disabled', 'sh2020' ),
				)
			);

			// Enable sticky header.
			$wp_customize->add_setting(
				'sh2020_sticky_header_pro_version',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => ( self::is_pro() ) ? true : false,
					'sanitize_callback' => array( get_called_class(), 'sanitize_checkbox' ),
					'transport'         => 'postMessage',
				)
			);
			$wp_customize->add_control(
				'sh2020_sticky_header_pro_version',
				array(
					'type'     => 'hidden',
					'section'  => STICKY_HEADER_2020_SECTION,
					'priority' => 2,
				)
			);

			// Append general header description.
			self::append_simple_text(
				$wp_customize,
				'header_sticky_custom_text_1',
				'<hr><br>' . esc_html__( 'Header General Settings', 'sh2020' ),
				__( 'The settings below will change the header height and will display a resized logo based on the header height and the vertical spacing (the logo and menu top and bottom spacing) you set here. The units can be <b>px</b>, <b>em</b>, <b>rem</b>, <b>%</b> or <b>vh</b> (it\'s recommended to use px for a more accurate result).', 'sh2020' ),
				2
			);

			// Sticky Header Colors.
			self::append_rgba_color(
				$wp_customize,
				'sh2020_header_sticky_bg_color',
				esc_html__( 'Background Color', 'sh2020' ),
				self::DEFAULT_COLOR_BG,
				3
			);

			// Minimum height for the general header.
			$wp_customize->add_setting(
				'sh2020_header_sticky_min_height',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => self::DEFAULT_HEIGHT,
					'sanitize_callback' => 'sanitize_text_field',
					'transport'         => 'postMessage',
				)
			);
			$wp_customize->add_control(
				'sh2020_header_sticky_min_height',
				array(
					'type'        => 'text',
					'section'     => STICKY_HEADER_2020_SECTION,
					'priority'    => 3,
					'label'       => __( 'Header Height', 'sh2020' ),
					'description' => __( 'default', 'sh2020' ) . ' ' . self::DEFAULT_HEIGHT,
					'input_attrs' => array(
						'style'       => 'width: 50%',
						'placeholder' => self::DEFAULT_HEIGHT,
					),
				)
			);

			// General header vertical spacing.
			$wp_customize->add_setting(
				'sh2020_header_sticky_vertical_spacing',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => self::DEFAULT_SPACING,
					'sanitize_callback' => 'sanitize_text_field',
					'transport'         => 'postMessage',
				)
			);
			$wp_customize->add_control(
				'sh2020_header_sticky_vertical_spacing',
				array(
					'type'        => 'text',
					'section'     => STICKY_HEADER_2020_SECTION,
					'priority'    => 4,
					'label'       => __( 'Vertical Spacing', 'sh2020' ),
					'description' => __( 'default', 'sh2020' ) . ' ' . self::DEFAULT_SPACING,
					'input_attrs' => array(
						'style'       => 'width: 50%',
						'placeholder' => self::DEFAULT_SPACING,
					),
				)
			);

			// Append general header shadow.
			self::append_simple_text(
				$wp_customize,
				'header_sticky_custom_text_5',
				'',
				'<hr>' . __( 'The header shadow options.', 'sh2020' ),
				5
			);
			if ( ! self::is_pro() ) {
				if ( ! self::is_pro() ) {
					self::append_only_pro_text( $wp_customize, array(
						esc_html__( 'Box Shadow Size', 'sh2020' ),
						esc_html__( 'Box Shadow Color', 'sh2020' ),
					), '5.1', 5 );
				}
			}

			// Append scroll minification description.
			self::append_simple_text(
				$wp_customize,
				'header_sticky_custom_text_2',
				'',
				'<hr>' . __( 'When you scroll the page, the header (also the logo) will reduce its height. The settings for the minified header can be adjusted below. To preview the changes you have to scroll up and down the page.', 'sh2020' ),
				7
			);

			// Minimum height for the general minified header.
			$wp_customize->add_setting(
				'sh2020_header_sticky_min_height_minified',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => self::DEFAULT_HEIGHT_MINI,
					'sanitize_callback' => 'sanitize_text_field',
					'transport'         => 'postMessage',
				)
			);
			$wp_customize->add_control(
				'sh2020_header_sticky_min_height_minified',
				array(
					'type'        => 'text',
					'section'     => STICKY_HEADER_2020_SECTION,
					'priority'    => 8,
					'label'       => __( 'Minified Header Height', 'sh2020' ),
					'description' => __( 'default', 'sh2020' ) . ' ' . self::DEFAULT_HEIGHT_MINI,
					'input_attrs' => array(
						'style'       => 'width: 50%',
						'placeholder' => self::DEFAULT_HEIGHT_MINI,
					),
				)
			);

			// General minified header vertical spacing.
			$wp_customize->add_setting(
				'sh2020_header_sticky_vertical_spacing_minified',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => self::DEFAULT_SPACING_MINI,
					'sanitize_callback' => 'sanitize_text_field',
					'transport'         => 'postMessage',
				)
			);
			$wp_customize->add_control(
				'sh2020_header_sticky_vertical_spacing_minified',
				array(
					'type'        => 'text',
					'section'     => STICKY_HEADER_2020_SECTION,
					'priority'    => 8,
					'label'       => __( 'Minified Vertical Spacing', 'sh2020' ),
					'description' => __( 'default', 'sh2020' ) . ' ' . self::DEFAULT_SPACING_MINI,
					'input_attrs' => array(
						'style'       => 'width: 50%',
						'placeholder' => self::DEFAULT_SPACING_MINI,
					),
				)
			);

			// Append mobile height description.
			self::append_simple_text(
				$wp_customize,
				'header_sticky_custom_text_3',
				'<hr><br>' . esc_html__( 'Mobile/Tablet Header', 'sh2020' ),
				__( 'The settings for the mobile/tablet devices header can be adjusted below.', 'sh2020' ),
				10
			);

			// Minimum height for the header on mobile.
			$wp_customize->add_setting(
				'sh2020_header_sticky_min_height_mobile',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => self::DEFAULT_HEIGHT_MOBILE,
					'sanitize_callback' => 'sanitize_text_field',
					'transport'         => 'postMessage',
				)
			);
			$wp_customize->add_control(
				'sh2020_header_sticky_min_height_mobile',
				array(
					'type'        => 'text',
					'section'     => STICKY_HEADER_2020_SECTION,
					'priority'    => 11,
					'label'       => __( 'Header Height', 'sh2020' ),
					'description' => __( 'default', 'sh2020' ) . ' ' . self::DEFAULT_HEIGHT_MOBILE,
					'input_attrs' => array(
						'style'       => 'width: 50%',
						'placeholder' => self::DEFAULT_HEIGHT_MOBILE,
					),
				)
			);

			// General minified header vertical spacing.
			$wp_customize->add_setting(
				'sh2020_header_sticky_vertical_spacing_mobile',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => self::DEFAULT_SPACING_MOBILE,
					'sanitize_callback' => 'sanitize_text_field',
					'transport'         => 'postMessage',
				)
			);
			$wp_customize->add_control(
				'sh2020_header_sticky_vertical_spacing_mobile',
				array(
					'type'        => 'text',
					'section'     => STICKY_HEADER_2020_SECTION,
					'priority'    => 12,
					'label'       => __( 'Mobile/Tablet Vertical Spacing', 'sh2020' ),
					'description' => __( 'default', 'sh2020' ) . ' ' . self::DEFAULT_SPACING_MOBILE,
					'input_attrs' => array(
						'style'       => 'width: 50%',
						'placeholder' => self::DEFAULT_SPACING_MOBILE,
					),
				)
			);

			if ( true === self::$show_pro ) {
				// Append colors description.
				self::append_simple_text(
					$wp_customize,
					'header_sticky_custom_text_4',
					'<hr><br>' . esc_html__( 'Header Elements Colors', 'sh2020' ),
					__( 'The settings below will applied to the elements inside the sticky header.', 'sh2020' ),
					14
				);
			}

			if ( ! self::is_pro() ) {
				self::append_only_pro_text( $wp_customize, array(
					esc_html__( 'Text/Separators Color', 'sh2020' ),
					esc_html__( 'Icons Color', 'sh2020' ),
					esc_html__( 'Links Color', 'sh2020' ),
					esc_html__( 'Links Hover Color', 'sh2020' ),
				), '4.1', 14 );
			}

			// Append hide labels description.
			self::append_simple_text(
				$wp_customize,
				'header_sticky_custom_text_6',
				'<hr><br>' . esc_html__( 'Menu & Submenu Extra Options', 'sh2020' ),
				__( 'Apart from the links color, you can adjust the icon, the submenu background and the current item color.', 'sh2020' ),
				30
			);

			if ( ! self::is_pro() ) {
				self::append_only_pro_text( $wp_customize, array(
					esc_html__( 'Icons Color for Menu & Submenu', 'sh2020' ),
					esc_html__( 'Link Color for Current Menu Item', 'sh2020' ),
				), '6.1', 31 );
			}

			self::append_rgba_color(
				$wp_customize,
				'sh2020_header_sticky_submenu_bg_color',
				esc_html__( 'Submenu Background Color', 'sh2020' ),
				self::DEFAULT_COLOR_BG_SUBMENU,
				31
			);

			// Enable hide search label.
			$wp_customize->add_setting(
				'sh2020_header_sticky_menu_no_decoration',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => false,
					'sanitize_callback' => array( get_called_class(), 'sanitize_checkbox' ),
					'transport'         => 'postMessage',
				)
			);
			$wp_customize->add_control(
				'sh2020_header_sticky_menu_no_decoration',
				array(
					'type'     => 'checkbox',
					'section'  => STICKY_HEADER_2020_SECTION,
					'priority' => 32,
					'label'    => __( 'No decoration for menu items', 'sh2020' ),
				)
			);

			// Append hide labels description.
			self::append_simple_text(
				$wp_customize,
				'header_sticky_custom_text_7',
				'<hr><br>' . esc_html__( 'Hide Labels', 'sh2020' ),
				__( 'Hide the texts under the menu and search icons.', 'sh2020' ),
				40
			);

			// Enable hide menu label.
			$wp_customize->add_setting(
				'sh2020_header_sticky_hide_menu_label',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => false,
					'sanitize_callback' => array( get_called_class(), 'sanitize_checkbox' ),
					'transport'         => 'postMessage',
				)
			);
			$wp_customize->add_control(
				'sh2020_header_sticky_hide_menu_label',
				array(
					'type'     => 'checkbox',
					'section'  => STICKY_HEADER_2020_SECTION,
					'priority' => 41,
					'label'    => __( 'Hide the menu label', 'sh2020' ),
				)
			);

			// Enable hide search label.
			$wp_customize->add_setting(
				'sh2020_header_sticky_hide_search_label',
				array(
					'capability'        => 'edit_theme_options',
					'default'           => false,
					'sanitize_callback' => array( get_called_class(), 'sanitize_checkbox' ),
					'transport'         => 'postMessage',
				)
			);
			$wp_customize->add_control(
				'sh2020_header_sticky_hide_search_label',
				array(
					'type'     => 'checkbox',
					'section'  => STICKY_HEADER_2020_SECTION,
					'priority' => 42,
					'label'    => __( 'Hide the search label', 'sh2020' ),
				)
			);
		}

		/**
		 * Append a custom color control with alpha opacity.
		 *
		 * @param object  $wp_customize Customize manager instance.
		 * @param string  $id           Settings id.
		 * @param string  $title        Control title.
		 * @param string  $default      Default value for the control.
		 * @param integer $priority     Control priority.
		 * @return void
		 */
		private static function append_rgba_color( $wp_customize, $id, $title, $default = '#ffffff', $priority = 20 ) {
			$wp_customize->add_setting(
				$id,
				array(
					'default'           => $default,
					'sanitize_callback' => array( get_called_class(), 'sanitize_rgba' ),
					'validate_callback' => array( get_called_class(), 'validate_rgba' ),
					'transport'         => 'postMessage',
				)
			);
			$wp_customize->add_control(
				new SH2020_Customize_RGBA_Color_Control(
					$wp_customize,
					$id,
					array(
						'label'        => $title,
						'section'      => STICKY_HEADER_2020_SECTION,
						'priority'     => $priority,
						'show_opacity' => true,
						'palette'      => array(
							'#a73050', // Red.
							'#f58231', // Orange.
							'#ffe119', // Yellow.
							'#bfef45', // Lime.
							'#3cb44b', // Green.
							'#42d4f4', // Cyan.
							'#4363d8', // Blue.
							'#911eb4', // Purple.
							'#f032e6', // Magenta.
							'#a9a9a9', // Grey.
							'#ffffff', // White.
							'#000000', // Black.
						),
						'transport'    => 'postMessage',
					)
				)
			);
		}

		/**
		 * Append a custom text.
		 *
		 * @param object $wp_customize Customize manager instance.
		 * @param string $id           Settings id.
		 * @param string $title        Control title.
		 * @param string $description  Control description.
		 * @param string $priority     Control proority.
		 * @return void
		 */
		private static function append_simple_text( $wp_customize, $id, $title = '', $description = '', $priority = '10' ) {
			if ( empty( $title ) && empty( $description ) ) {
				// Fail-fast.
				return;
			}
			$wp_customize->add_setting(
				$id,
				array()
			);
			$wp_customize->add_control(
				new SH2020_Customize_Simple_Text_Control(
					$wp_customize,
					$id,
					array(
						'section'       => STICKY_HEADER_2020_SECTION,
						'priority'      => $priority,
						'label'         => $title,
						'description'   => $description,
					)
				)
			);
		}

		/**
		 * Append only PRO text.
		 *
		 * @param  object  $wp_customize Customize manager instance.
		 * @param  mixed   $list         Items to be mentioned.
		 * @param  string  $suffix       Control suffix.
		 * @param  integer $priority     Control priority.
		 * @return void
		 */
		public static function append_only_pro_text( $wp_customize, $list = array(), $suffix = '', $priority = 10 ) {
			if ( false === self::$show_pro ) {
				return;
			}
			$text = '';
			if ( is_scalar( $list ) ) {
				$list = array( $list );
			}
			foreach ( $list as $value ) {
				$text .= '<li><label class="customize-control-title">' . $value . '</label> <em>' . sprintf(
					// Translators: %1$s - link to pro version.
					__( 'Available in the %1$s version.', 'sh2020' ),
					self::PRO_LABEL
				) . '</em><br>&nbsp;</li>';
			}
			self::append_simple_text(
				$wp_customize,
				'header_sticky_custom_text_' . esc_attr( $suffix ),
				'',
				'</li>' . $text . '<li>',
				$priority
			);
		}

		/**
		 * Sanitize boolean for checkbox.
		 *
		 * @param bool $checked Wethere or not a blox is checked.
		 */
		public static function sanitize_checkbox( $checked ) {
			return ( ( isset( $checked ) && true === $checked ) ? true : false );
		}

		/**
		 * Validate alpha settings.
		 *
		 * @param  boolean $validity If the setting value is valid.
		 * @param  string  $value    The setting value.
		 * @return boolean
		 */
		public static function validate_rgba( $validity, $value = '' ) {
			$validity = true;
			return $validity;
		}

		/**
		 * Sanitize alpha settings.
		 *
		 * @param  string $value The setting value.
		 * @return string
		 */
		public static function sanitize_rgba( $value ) {
			// @TODO - maybe a regex.
			return $value;
		}

		/**
		 * Used by hook: 'customize_preview_init' to enqueue the theme customizer script.
		 *
		 * @return void
		 */
		public static function sticky_header_2020_customizer_live_preview() {
			wp_enqueue_script(
				'sticky_header_2020-themecustomizer',
				plugin_dir_url( __FILE__ ) . 'assets/js/theme-customizer.js',
				array( 'jquery', 'customize-preview' ),
				STICKY_HEADER_2020_VER . self::ASSETS_VER,
				true
			);
		}

		/**
		 * Output custom styles from settings.
		 *
		 * @return void
		 */
		public static function output_custom_styles() {
			$selector          = get_theme_mod( 'sh2020_header_sticky_selector', self::DEFAULT_SELECTOR );
			$height            = get_theme_mod( 'sh2020_header_sticky_min_height', self::DEFAULT_HEIGHT );
			$spacing           = get_theme_mod( 'sh2020_header_sticky_vertical_spacing', self::DEFAULT_SPACING );
			$height_mini       = get_theme_mod( 'sh2020_header_sticky_min_height_minified', self::DEFAULT_HEIGHT_MINI );
			$spacing_mini      = get_theme_mod( 'sh2020_header_sticky_vertical_spacing_minified', self::DEFAULT_SPACING_MINI );
			$height_mobile     = get_theme_mod( 'sh2020_header_sticky_min_height_mobile', self::DEFAULT_HEIGHT_MOBILE );
			$spacing_mobile    = get_theme_mod( 'sh2020_header_sticky_vertical_spacing_mobile', self::DEFAULT_SPACING_MOBILE );
			$shadow_size       = get_theme_mod( 'sh2020_header_sticky_box_shadow_size', self::DEFAULT_SHADOW_SIZE );
			$shadow_color      = get_theme_mod( 'sh2020_header_sticky_box_shadow_color', self::DEFAULT_SHADOW_COLOR );
			$color_mainbg      = get_theme_mod( 'sh2020_header_sticky_bg_color', self::DEFAULT_COLOR_BG );
			$color_submenu_bg  = get_theme_mod( 'sh2020_header_sticky_submenu_bg_color', self::DEFAULT_COLOR_BG_SUBMENU );
			$color_text        = get_theme_mod( 'sh2020_header_sticky_text_color', self::DEFAULT_COLOR_TEXT );
			$color_icons       = get_theme_mod( 'sh2020_header_sticky_icons_color', self::DEFAULT_COLOR_ICONS );
			$color_menu_icons  = get_theme_mod( 'sh2020_header_sticky_menu_icons_color', self::DEFAULT_COLOR_ICONS );
			$color_links       = get_theme_mod( 'sh2020_header_sticky_links_color', self::DEFAULT_COLOR_LINKS );
			$color_menu_clinks = get_theme_mod( 'sh2020_header_sticky_menu_current_links_color', self::DEFAULT_COLOR_LINKS );
			$color_links_hover = get_theme_mod( 'sh2020_header_sticky_links_hover_color', self::DEFAULT_COLOR_LINKS_HOVER );
			$hide_label_menu   = get_theme_mod( 'sh2020_header_sticky_hide_menu_label', false );
			$hide_label_search = get_theme_mod( 'sh2020_header_sticky_hide_search_label', false );
			$menu_no_deco      = get_theme_mod( 'sh2020_header_sticky_menu_no_decoration', false );

			?>

			body.sticky-header * {
				outline: none;
			}
			body.sticky-header.admin-bar <?php echo esc_attr( $selector ); ?> {
				top: 32px !important
			}
			body.sticky-header .menu-modal.active {
				z-index: 110;
			}

			body.sticky-header {
				scroll-behavior: smooth;
				padding-top: <?php echo esc_attr( $height ); ?>;
				scroll-padding: <?php echo esc_attr( $height ); ?>;
			}
			body.sticky-header <?php echo esc_attr( $selector ); ?> {
				position:fixed !important; top:0 !important;
				background: <?php echo esc_attr( $color_mainbg ); ?>;
				background-color: <?php echo esc_attr( $color_mainbg ); ?>;
				display: block;
				width: 100%;
				z-index:100;
				background-attachment: fixed;
				<?php if ( self::is_pro() ) : ?>
					box-shadow: 0 0 <?php echo esc_attr( $shadow_size ); ?> 0 <?php echo esc_attr( $shadow_color ); ?>;
				<?php endif; ?>
				min-height: <?php echo esc_attr( $height ); ?>;
				height: <?php echo esc_attr( $height ); ?>;
				-moz-transition:all 0.2s ease-in;
				-webkit-transition:all 0.2s ease-in;
				-o-transition:all 0.2s ease-in;
				transition:all 0.2s ease-in;
			}
			body.sticky-header <?php echo esc_attr( $selector ); ?> .header-inner {
				padding: <?php echo esc_attr( $spacing ); ?> 0;
			}
			body.sticky-header <?php echo esc_attr( $selector ); ?> .custom-logo {
				max-height: calc(<?php echo esc_attr( $height ); ?> - (<?php echo esc_attr( $spacing ); ?> * 2) );
				width: auto;
			}

			/* The minified desktop and tablet header and logo */
			body.sticky-header <?php echo esc_attr( $selector ); ?>.sticky-header-minified {
				min-height: <?php echo esc_attr( $height_mini ); ?>;
				height: <?php echo esc_attr( $height_mini ); ?>;
			}
			body.sticky-header <?php echo esc_attr( $selector ); ?>.sticky-header-minified .header-inner {
				padding: <?php echo esc_attr( $spacing_mini ); ?> 0;
			}
			body.sticky-header <?php echo esc_attr( $selector ); ?>.sticky-header-minified .custom-logo {
				max-height: calc(<?php echo esc_attr( $height_mini ); ?> - (<?php echo esc_attr( $spacing_mini ); ?> * 2) );
				width: auto;
			}

			body.template-cover.sticky-header .entry-header {
				bottom: <?php echo esc_attr( $height ); ?>;
			}

			@media (max-width: 782px) {
				body.sticky-header {
					padding-top: <?php echo esc_attr( $height_mobile ); ?>;
					scroll-padding: <?php echo esc_attr( $height_mobile ); ?>;
				}
				body.sticky-header.admin-bar <?php echo esc_attr( $selector ); ?> {
					top: 46px !important;
				}
				body.sticky-header.admin-bar <?php echo esc_attr( $selector ); ?>.sticky-header-minified {
					top: 0px !important;
				}

				body.sticky-header <?php echo esc_attr( $selector ); ?> .header-inner,
				body.sticky-header <?php echo esc_attr( $selector ); ?>.sticky-header-minified .header-inner {
					padding: <?php echo esc_attr( $spacing_mobile ); ?> 0;
				}

				body.sticky-header <?php echo esc_attr( $selector ); ?>,
				body.sticky-header <?php echo esc_attr( $selector ); ?>.sticky-header-minified {
					min-height: <?php echo esc_attr( $height_mobile ); ?>;
					height: <?php echo esc_attr( $height_mobile ); ?>;
				}
				body.template-cover.sticky-header .entry-header,
				body.template-cover.sticky-header.sticky-header-minified .entry-header {
					bottom: <?php echo esc_attr( $height_mobile ); ?>;
				}

				body.sticky-header <?php echo esc_attr( $selector ); ?> .custom-logo,
				body.sticky-header <?php echo esc_attr( $selector ); ?>.sticky-header-minified .custom-logo {
					max-height: calc(<?php echo esc_attr( $height_mobile ); ?> - (<?php echo esc_attr( $spacing_mobile ); ?> * 2) );
					width: auto;
				}
			}

			<?php if ( self::is_pro() ) : ?>
				body.sticky-header .toggle-icon,
				body.sticky-header .toggle-wrapper .svg-icon {
					color: <?php echo esc_attr( $color_icons ); ?>;
				}
				body.sticky-header .icon,
				body.sticky-header.overlay-header .primary-menu > li > .icon
				body.sticky-header:not(.overlay-header) .primary-menu > li > .icon {
					color: <?php echo esc_attr( $color_menu_icons ); ?> !important;
				}
				body.sticky-header .site-description,
				body.sticky-header .site-title,
				body.sticky-header .site-title *,
				body.sticky-header:not(.overlay-header) .nav-toggle .toggle-text,
				body.sticky-header:not(.overlay-header) .toggle.nav-toggle .toggle-inner .toggle-text,
				body.sticky-header:not(.overlay-header) .toggle.search-toggle .toggle-inner .toggle-text,
				body.sticky-header.overlay-header .header-inner {
					color: <?php echo esc_attr( $color_text ); ?>;
				}
				body.sticky-header .header-inner .toggle-wrapper::before {
					background: <?php echo esc_attr( $color_text ); ?> !important;
				}
			<?php endif; ?>

			body.sticky-header.overlay-header .primary-menu ul,
			body.sticky-header:not(.overlay-header) .primary-menu ul {
				background: <?php echo esc_attr( $color_submenu_bg ); ?>;
			}

			body.sticky-header.overlay-header .primary-menu > li > ul:after,
			body.sticky-header:not(.overlay-header) .primary-menu > li > ul:after {
				border-bottom-color: <?php echo esc_attr( $color_submenu_bg ); ?>;
			}
			body.sticky-header.overlay-header .primary-menu ul ul:after,
			body.sticky-header:not(.overlay-header) .primary-menu ul ul:after {
				border-left-color: <?php echo esc_attr( $color_submenu_bg ); ?>;
			}

			body.sticky-header:not(.overlay-header) .primary-menu > li.current-menu-item > a,
			body.sticky-header:not(.overlay-header) .primary-menu .sub-menu > li.current-menu-item > a {
				color: <?php echo esc_attr( $color_menu_clinks ); ?>;
				<?php if ( true === $menu_no_deco ) : ?>
					text-decoration: none;
				<?php endif; ?>
			}
			<?php if ( true === $menu_no_deco ) : ?>
				body.sticky-header .primary-menu a:hover, body.sticky-header .primary-menu a:focus, body.sticky-header .primary-menu .current_page_ancestor {
					text-decoration: none !important;
				}
			<?php endif; ?>

			<?php if ( self::is_pro() ) : ?>
				body.sticky-header.overlay-header .primary-menu a,
				body.sticky-header:not(.overlay-header) .primary-menu > li > a,
				body.sticky-header:not(.overlay-header) .primary-menu .sub-menu > li > a {
					color: <?php echo esc_attr( $color_links ); ?>;
				}
				body.sticky-header.overlay-header .primary-menu li:hover > a,
				body.sticky-header:not(.overlay-header) .primary-menu li:hover > a {
					color: <?php echo esc_attr( $color_links_hover ); ?>;
				}
			<?php endif; ?>

			<?php if ( ! empty( $hide_label_menu ) ) : ?>
				body.sticky-header.overlay-header .toggle.nav-toggle .toggle-inner .toggle-text,
				body.sticky-header:not(.overlay-header) .toggle.nav-toggle .toggle-inner .toggle-text {
					display:none;
				}
			<?php endif; ?>
			<?php if ( ! empty( $hide_label_search ) ) : ?>
				body.sticky-header.overlay-header .toggle.search-toggle .toggle-inner .toggle-text,
				body.sticky-header:not(.overlay-header) .toggle.search-toggle .toggle-inner .toggle-text {
					display:none;
				}
			<?php endif; ?>
			<?php
		}

		/**
		 * Update the custom CSS file from the computed customizer CSS and the update version,
		 * so this can be enqueeued as any stylesheet.
		 *
		 * @return void
		 */
		public static function update_custom_styles() {
			// Update the option that will be used as the custom CSS version.
			update_option( 'sticky-header-2020-last-update', date( 'Ymd.His', time() ) );

			// Actually compute the content to be saved as the custom CSS.
			ob_start();
			self::output_custom_styles();
			$content = ob_get_clean();

			// Minify the output.
			$content = self::custom_minify( $content, true );

			// Write the custom CSS content to the database.
			update_option( 'sticky-header-2020-styles', $content );
		}

		/**
		 * Output custom styles from settings.
		 *
		 * @return void
		 */
		public static function output_custom_scripts() {
			$selector      = str_replace( '#', '', get_theme_mod( 'sh2020_header_sticky_selector', self::DEFAULT_SELECTOR ) );
			$height        = get_theme_mod( 'sh2020_header_sticky_min_height', self::DEFAULT_HEIGHT );
			$height_mini   = get_theme_mod( 'sh2020_header_sticky_min_height_minified', self::DEFAULT_HEIGHT_MINI );
			$height_mobile = get_theme_mod( 'sh2020_header_sticky_min_height_mobile', self::DEFAULT_HEIGHT_MOBILE );
			$scroll        = min( (int) $height, (int) $height_mini, (int) $height_mobile );
			$scroll        = ( empty( $scroll ) || ( ! empty( $scroll ) && $scroll > 110 ) ) ? 110 : $scroll;
			?>
			/* Script to toggle the custom sticky header class on scroll */
			let stk_scroll_pos = 0;
			let stk_ticking = false;

			let eventMin = new CustomEvent('stickyHeaderMinified', {
				done: true
			});
			let eventMax = new CustomEvent('stickyHeaderMaxified', {
				done: true
			});
			function toggleLogoClass(scroll_pos) {
				setTimeout(function(){
					/* Do something with the scroll position. */
					if ( scroll_pos > <?php echo (int) $scroll; ?> ) {
						var sel = document.getElementById('<?php echo esc_attr( $selector ); ?>');
						if (sel.classList.contains('sticky-header-minified')) {
							/* Nothing to do, the class was added previously. */
						} else {
							sel.classList.add('sticky-header-minified');
							document.getElementsByTagName('body')[0].classList.add('with-sticky-header-minified');
							window.dispatchEvent(eventMin);
						}
					} else {
						var sel = document.getElementById('<?php echo esc_attr( $selector ); ?>');
						if (! sel.classList.contains('sticky-header-minified')) {
							/* Nothing to do, the class was removed previously. */
						} else {
							sel.classList.remove('sticky-header-minified');
							document.getElementsByTagName('body')[0].classList.remove('with-sticky-header-minified');
							window.dispatchEvent(eventMax);
						}
					}
				}, 200);
			}
			window.addEventListener('scroll', function(e) {
				stk_scroll_pos = window.scrollY;
				if ( ! stk_ticking ) {
					window.requestAnimationFrame(function() {
						toggleLogoClass(stk_scroll_pos);
						stk_ticking = false;
					});
					stk_ticking = true;
				}
			});

			/* Listen for scroll to top click */
			document.querySelectorAll('a[href="#site-header"]').forEach(item => {
				item.addEventListener('click', event => {
					document.body.scrollTop = 0;
					document.documentElement.scrollTop = 0;
				});
			});

			/* This is only for debug, if you want to extend the code with your own script you can listen for these two events like in the example below */
			/*
			window.addEventListener('stickyHeaderMinified', function(e) {
				event.preventDefault();
				alert('Sticky header was minified', e);
			});
			window.addEventListener('stickyHeaderMaxified', function(e) {
				event.preventDefault();
				alert('Sticky header was maxified', e);
			});
			*/
			<?php
		}

		/**
		 * Update the custom CSS file from the computed customizer CSS and the update version,
		 * so this can be enqueeued as any stylesheet.
		 *
		 * @return void
		 */
		public static function update_custom_scripts() {
			// Update the option that will be used as the custom CSS version.
			update_option( 'sticky-header-2020-last-update', date( 'Ymd.His', time() ) );

			// Actually compute the content to be saved as the custom CSS.
			ob_start();
			self::output_custom_scripts();
			$content = ob_get_clean();

			// Minify the output.
			$content = self::custom_minify( $content );

			// Write the custom scripts content to the database.
			update_option( 'sticky-header-2020-scripts', $content );
		}

		/**
		 * Custom minify content.
		 *
		 * @param  string  $content String to be minified.
		 * @param  boolean $is_css  String to CSS or not.
		 * @return string
		 */
		public static function custom_minify( $content, $is_css = false ) {
			// Minify the output.
			$content = trim( $content );

			// Remove space after colons.
			$content = str_replace( ': ', ':', $content );

			// Remove whitespace.
			$content = str_replace( array( "\r\n", "\r", "\n", "\t" ), '', $content );

			// Remove spaces that might still be left where we know they aren't needed.
			$content = preg_replace( '/\s*([\{\}>~:;,])\s*/', '$1', $content );

			if ( true === $is_css ) {
				// Remove last semi-colon in a block.
				$content = preg_replace( '/;\}/', '}', $content );
			}

			return $content;
		}

		/**
		 * Enqueue the computed custom CSS and the custom scripts (this is generated by the customizer),
		 * so we don't compute this for each page load.
		 *
		 * @return void
		 */
		public static function enqueue_custom_styles() {
			// Enqueue the static styles.
			wp_enqueue_style(
				'sticky-header-2020-custom',
				plugin_dir_url( __FILE__ ) . 'assets/css/fed.css',
				array(),
				get_option( 'sticky-header-2020-last-update', STICKY_HEADER_2020_VER )
			);

			// Output the inline styles.
			wp_add_inline_style( 'sticky-header-2020-custom', get_option( 'sticky-header-2020-styles' ) );

			// Enqueue the static script.
			wp_enqueue_script(
				'sticky-header-2020-custom',
				plugin_dir_url( __FILE__ ) . 'assets/js/fed.js',
				array(),
				get_option( 'sticky-header-2020-last-update', STICKY_HEADER_2020_VER ),
				true
			);

			// Output the inline script.
			wp_add_inline_script( 'sticky-header-2020-custom', get_option( 'sticky-header-2020-scripts' ) );
		}

		/**
		 * Add the body sticky header class if the theme option is enabled.
		 *
		 * @param  array $classes Body classes.
		 * @return array
		 */
		public static function sticky_header_2020_class( $classes ) {
			$use_sticky = get_theme_mod( 'sh2020_enable_header_sticky' );
			if ( ! empty( $use_sticky ) ) {
				$classes[] = 'sticky-header';
			}
			return $classes;
		}

		/**
		 * Execute actions on activate plugin.
		 *
		 * @return void
		 */
		public static function activate_plugin() {
			set_theme_mod( 'sh2020_enable_header_sticky', true );
			set_theme_mod( 'sh2020_header_sticky_selector', '#site-header' );
			self::update_custom_styles();
			self::update_custom_scripts();

			set_transient( self::PLUGIN_TRANSIENT, true );
			set_transient( self::PLUGIN_TRANSIENT . '_adons_notice', true );
		}

		/**
		 * Execute cleanup actions on activate plugin.
		 *
		 * @return void
		 */
		public static function deactivate_plugin() {
			$remove = get_theme_mod( 'sh2020_enable_header_sticky_keep_setting', false );
			if ( true === $remove ) {
				$opt = array( 'sh2020_enable_header_sticky', 'sh2020_header_sticky_selector', 'sh2020_header_sticky_bg_color', 'sh2020_header_sticky_min_height', 'sh2020_header_sticky_vertical_spacing', 'sh2020_header_sticky_box_shadow_color', 'sh2020_header_sticky_text_color', 'sh2020_header_sticky_icons_color', 'sh2020_header_sticky_links_color', 'sh2020_header_sticky_hide_menu_label', 'sh2020_header_sticky_hide_search_label', 'sh2020_header_sticky_submenu_bg_color', 'sh2020_header_sticky_min_height_minified', 'sh2020_header_sticky_vertical_spacing_minified', 'sh2020_header_sticky_min_height_mobile', 'sh2020_header_sticky_vertical_spacing_mobile', 'sh2020_header_sticky_box_shadow_size', 'sh2020_header_sticky_links_hover_color', 'sh2020_header_sticky_menu_icons_color', 'sh2020_header_sticky_menu_current_links_color', 'sh2020_header_sticky_menu_no_decoration', 'sh2020_show_hints', 'sh2020_enable_header_sticky_keep_setting' );
				foreach ( $opt as $name ) {
					remove_theme_mod( $name );
				}

				delete_option( 'sticky-header-2020-last-update' );
				delete_option( 'sticky-header-2020-styles' );
				delete_option( 'sticky-header-2020-scripts' );
				self::admin_notices_cleanup( false );
			}
		}

		/**
		 * Execute notices cleanup.
		 *
		 * @param  boolean $ajax Is AJAX call.
		 * @return void
		 */
		public static function admin_notices_cleanup( $ajax = true ) {
			// Delete transient, only display this notice once.
			delete_transient( self::PLUGIN_TRANSIENT );

			if ( true === $ajax ) {
				// No need to continue.
				wp_die();
			}
		}

		/**
		 * Admin notices.
		 *
		 * @return void
		 */
		public static function admin_notices() {
			$maybe_trans = get_transient( self::PLUGIN_TRANSIENT );
			if ( ! empty( $maybe_trans ) ) {
				?>
				<style>.notice.<?php echo esc_attr( self::PLUGIN_TRANSIENT ); ?>{background:rgba(140,78,164,0.3);border-left-color:rgb(140,78,164); padding-left:15px !important; padding-bottom: 15px; padding-right: 0 !important;}.notice.<?php echo esc_attr( self::PLUGIN_TRANSIENT ); ?> h3{margin-bottom: 15px;}.notice.<?php echo esc_attr( self::PLUGIN_TRANSIENT ); ?> img{max-width: 100%}.notice.<?php echo esc_attr( self::PLUGIN_TRANSIENT ); ?> .button.button-primary{vertical-align: middle; background:#33293f; border-color:#33293f; line-height: 24px; min-height: 24px; text-transform: uppercase;}.notice.<?php echo esc_attr( self::PLUGIN_TRANSIENT ); ?> .button.button-primary:hover {color: #C9F427} .notice.<?php echo esc_attr( self::PLUGIN_TRANSIENT ); ?> .notice-other-items {padding:10px; width: calc(100% - 3px); margin-left:-16px; color: #FFF; background-color: rgb(140,78,164)}.notice.<?php echo esc_attr( self::PLUGIN_TRANSIENT ); ?> .button.button-primary .dashicons{ color:#C9F427; line-height: 24px;}.notice .pro-item:before, .notice .pro-item-after:after { display: inline-block; box-sizing: border-box; position: relative; content: 'PRO'; background: #8ec920; border: 2px solid #ffffff; color: #FFF; padding: 0 3px; line-height: 16px; font-size: 11px; text-align: center; font-style: normal; vertical-align: middle; border-radius: 3px; margin-right: 5px; box-shadow: 0 0 5px 0 rgba(0,0,0,0.3); margin-top:-2px;} .notice .pro-item-after:after {margin-right:0; margin-left: 5px;}</style>
				<script>(function($) { $(document).ready(function() { var $notice = $('.notice.<?php echo esc_attr( self::PLUGIN_TRANSIENT ); ?>'); var $button = $notice.find('.notice-dismiss'); $notice.unbind('click'); $button.unbind('click'); $notice.on('click', '.notice-dismiss', function(e) { $.get( $notice.data('dismissurl') ); }); }); })(jQuery);</script>

				<div class="updated notice is-dismissible <?php echo esc_attr( self::PLUGIN_TRANSIENT ); ?>"
					data-dismissurl="<?php echo esc_url( admin_url( 'admin-ajax.php?action=sh2020-plugin-deactivate-notice' ) ); ?>">
					<p>
						<?php
						$maybe_pro = '';
						if ( ! self::is_pro() ) {
							$maybe_pro = sprintf(
								// Translators: %1$s - extensions URL.
								__( 'You are using the free version. See the <a class="pro-item button button-primary" href="%1$s" target="_blank">version</a> details. ', 'sh2020' ),
								esc_url( self::LINK_PRO_VERSION )
							);
						} else {
							$maybe_pro = sprintf(
								// Translators: %1$s - pro version label, %2$s - PRO URL.
								__( 'Thank you for purchasing the <a class="pro-item button button-primary" href="%1$s" target="_blank">version</a>. ', 'sh2020' ),
								self::LINK_PRO_VERSION
							);
						}

						$other_notice = sprintf(
							// Translators: %1$s - extensions URL.
							__( '%5$sCheck out my other <a class="button button-primary" href="%1$s" target="_blank">%2$s free plugins</a> on WordPress.org and the <a class="button button-primary" href="%3$s" target="_blank">%4$s premium extensions</a> available!', 'sh2020' ),
							'https://profiles.wordpress.org/iulia-cazan/#content-plugins',
							'<span class="dashicons dashicons-heart"></span>',
							'https://iuliacazan.ro/shop/',
							'<span class="dashicons dashicons-star-filled"></span>',
							$maybe_pro
						);

						echo wp_kses_post( sprintf(
							// Translators: %1$s - image URL, %2$s - icon URL, %3$s - donate URL, %4$s - link style, %5$s - icon style, %6$s - rating.
							__( '<a href="%3$s" target="_blank"%4$s><img src="%1$s"></a><a href="%9$s"><img src="%2$s"%5$s></a> <h3>%8$s plugin was activated!</h3> This plugin is free to use, but not to operate. Please consider supporting my services by making a <a href="%3$s" target="_blank">donation</a>. It would make me very happy if you would leave a %6$s rating. %7$s', 'sh2020' ),
							esc_url( plugin_dir_url( __FILE__ ) . '/assets/images/buy-me-a-coffee.png' ),
							esc_url( plugin_dir_url( __FILE__ ) . '/assets/images/icon-128x128.png' ),
							'https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=JJA37EHZXWUTJ&item_name=Support for development and maintenance (' . urlencode( self::PLUGIN_NAME ) . ')',
							' style="float:right; margin:20px"',
							' style="float:left; margin-right:20px; margin-top:10px; width:86px"',
							'<a href="' . self::PLUGIN_SUPPORT_URL . 'reviews/?rate=5#new-post" class="rating" target="_blank" title="' . esc_attr( 'A huge thanks in advance!', 'sh2020' ) . '">★★★★★</a>',
							__( 'A huge thanks in advance!', 'sh2020' ),
							__( 'Sticky Header 2020', 'sh2020' ),
							'#'
						) );
						?>
						<div class="clear"></div>
					</p>
					<div class="notice-other-items"><?php echo wp_kses_post( $other_notice ); ?></div>
				</div>
				<?php
			}
		}

		/**
		 * Load text domain for internalization.
		 */
		public static function load_textdomain() {
			load_plugin_textdomain( 'sh2020', false, basename( dirname( __FILE__ ) ) . '/langs/' );
		}

		/**
		 * Add the plugin settings and plugin URL links.
		 *
		 * @param array $links The plugin links.
		 */
		public static function plugin_action_links( $links ) {
			$customizer = 'sh2020_sticky_header_options';
			$plugin_url = self::LINK_LIGHT_VERSION;
			$hints      = get_theme_mod( 'sh2020_show_hints' );
			if ( self::is_pro() ) {
				if ( true === self::$show_pro ) {
					$customizer = 'sh2020_sticky_header_options_pro';
				} else {
					$customizer = 'sh2020_sticky_header_options_pro_simple';
				}
				$plugin_url = self::LINK_PRO_VERSION;
			}

			$all   = array();
			$all[] = '<a href="' . esc_url( admin_url( 'customize.php?autofocus[section]=' . $customizer ) ) . '" target="_blank">' . esc_html__( 'Settings', 'sh2020' ) . '</a>';
			if ( true === $hints ) {
				$all[] = '<a href="' . esc_url( admin_url( 'customize.php?autofocus[section]=' . $customizer . '&sh2020-hide-hints=on' ) ) . '" target="_blank">' . esc_html__( 'Hide Hints', 'sh2020' ) . '</a>';
			} else {
				$all[] = '<a href="' . esc_url( admin_url( 'customize.php?autofocus[section]=' . $customizer . '&sh2020-show-hints=on' ) ) . '" target="_blank">' . esc_html__( 'Show Hints', 'sh2020' ) . '</a>';
			}
			$all[] = '<a href="' . esc_url( $plugin_url ) . '">' . esc_html__( 'Plugin URL', 'sh2020' ) . '</a>';
			$all   = array_merge( $all, $links );
			return $all;
		}
	}
}

// Instantiate the class.
$sticky_header_2020 = Sticky_Header_2020::get_instance();

// Register activation and deactivation actions.
register_activation_hook( __FILE__, array( $sticky_header_2020, 'activate_plugin' ) );
register_deactivation_hook( __FILE__, array( $sticky_header_2020, 'deactivate_plugin' ) );
